Re-exports
Modules
- re-exported for easier access (no
use thetime::ntp::System;, justuse thetime::System;) - re-exported for easier access (no
use thetime::system::System;, justuse thetime::System;) - Timezones - a list of common timezones Note: some names clash, examples Arabia Standard Time (AST) and Atlantic Standard Time (ATST), so we lengthen as shown above
Enums
- An enum to represent whether a time is in the past, present or future
Constants
- Magic number for Macos epoch (offset between 1904 and 1970)
- Magic number for Macos Absolute epoch (offset between 2001 and 1970)
- Magic number for SAS 4GL (offset betwenn 1960 and 1970)
- Offset between 1601 and 1970
- Reference time
Traits
- A trait so that we can use chrono::Duration and core::time::Duration interchangeably in the
Time::add_durationfunction - Provides wrappers on integer std types to parse into time structs, and also to pretty print timestamp integers
- Provides wrappers on string std types to parse into time structs
- Implements the core functionality of the library
- Implements the diff functions (optional)
Functions
- Returns the current time in seconds since Unix epoch